@@ -183,7 +183,7 @@ description_set_func (GtkTreeViewColumn *tree_column,
 		  "text", key_entry->description != NULL ?
 			  key_entry->description : _("<Unknown Action>"),
 		  NULL);
-  else 
+  else
     g_object_set (cell,
 		  "editable", FALSE, NULL);
 }
@@ -413,7 +413,7 @@ key_match (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer d
 		      KEYENTRY_COLUMN, &element,
 		      -1);
 
-  if (element && g_strcmp0 (element->gconf_key, match_data->key) == 0) 
+  if (element && g_strcmp0 (element->gconf_key, match_data->key) == 0)
     {
       match_data->found = TRUE;
       return TRUE;
@@ -422,13 +422,13 @@ key_match (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer d
   return FALSE;
 }
 
-static gboolean 
+static gboolean
 key_is_already_shown (GtkTreeModel *model, const KeyListEntry *entry)
 {
   KeyMatchData data;
 
   data.key = entry->name;
-  data.found = FALSE; 
+  data.found = FALSE;
   gtk_tree_model_foreach (model, key_match, &data);
 
   return data.found;
@@ -502,12 +502,12 @@ find_section (GtkTreeModel *model,
 {
   gint i, j;
   gboolean found;
-   
+
   i = gtk_tree_model_iter_n_children (model, NULL);
   found = FALSE;
   gtk_tree_model_get_iter_first (model, iter);
   for (j = 0; j < i; j++)
-    { 
+    {
       char *description = NULL;
 
       gtk_tree_model_iter_next (model, iter);
@@ -544,7 +544,7 @@ append_keys_to_tree (GladeXML           *dialog,
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (WID ("shortcut_treeview")));
 
   /* Try to find a section parent iter, if it already exists */
-  find_section (model, &iter, title); 
+  find_section (model, &iter, title);
   parent_iter = iter;
 
   i = 0;
@@ -606,6 +606,14 @@ append_keys_to_tree (GladeXML           *dialog,
             }
         }
 
+      if (description == NULL)
+        {
+	  /* Only print a warning for keys that should have a schema */
+	  if (keys_list[j].description_name == NULL)
+	    g_warning ("No description for key '%s'", key_string);
+	  description = g_path_get_basename (key_string);
+	}
+
       if (keys_list[j].cmd_name != NULL)
         {
           command = gconf_client_get_string (client, keys_list[j].cmd_name, NULL);
@@ -661,7 +669,7 @@ append_keys_to_tree (GladeXML           *dialog,
 			  -1);
       gtk_tree_view_expand_all (GTK_TREE_VIEW (WID ("shortcut_treeview")));
     }
-  
+
   g_object_unref (client);
 
   /* Don't show an empty section */
@@ -961,7 +969,7 @@ reload_key_entries (gpointer wm_name, GladeXML *dialog)
     }
   g_list_free (list);
 
-  /* Load custom shortcuts _after_ system-provided ones, 
+  /* Load custom shortcuts _after_ system-provided ones,
    * since some of the custom shortcuts may also be listed
    * in a file. Loading the custom shortcuts last makes
    * such keys not show up in the custom section.
@@ -1367,9 +1375,9 @@ edit_custom_shortcut (KeyEntry *key)
   const gchar *text;
   gboolean ret;
 
-  gtk_entry_set_text (GTK_ENTRY (custom_shortcut_name_entry), key->description);
+  gtk_entry_set_text (GTK_ENTRY (custom_shortcut_name_entry), key->description ? key->description : "");
   gtk_widget_set_sensitive (custom_shortcut_name_entry, key->desc_editable);
-  gtk_entry_set_text (GTK_ENTRY (custom_shortcut_command_entry), key->command);
+  gtk_entry_set_text (GTK_ENTRY (custom_shortcut_command_entry), key->command ? key->command : "");
   gtk_widget_set_sensitive (custom_shortcut_command_entry, key->cmd_editable);
 
   gtk_window_present (GTK_WINDOW (custom_shortcut_dialog));
@@ -1450,10 +1458,19 @@ update_custom_shortcut (GtkTreeModel *model, GtkTreeIter *iter)
 
   edit_custom_shortcut (key);
   if (key->command == NULL || key->command[0] == '\0')
-    remove_custom_shortcut (model, iter);
-  else 
-    gtk_tree_store_set (GTK_TREE_STORE (model), iter, 
-	                KEYENTRY_COLUMN, key, -1);
+    {
+      remove_custom_shortcut (model, iter);
+    }
+  else
+    {
+      GConfClient *client;
+
+      gtk_tree_store_set (GTK_TREE_STORE (model), iter,
+			  KEYENTRY_COLUMN, key, -1);
+      client = gconf_client_get_default ();
+      gconf_client_set_string (client, key->desc_gconf_key, key->description, NULL);
+      g_object_unref (client);
+    }
 }
 
 static gchar *
@@ -1504,7 +1521,7 @@ add_custom_shortcut (GtkTreeView  *tree_view,
   dir = find_free_gconf_key (&error);
   if (dir == NULL)
     {
-      show_error (gtk_widget_get_toplevel (tree_view), error);
+      show_error (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tree_view))), error);
 
       g_error_free (error);
       return;
@@ -1737,7 +1754,7 @@ selection_changed (GtkTreeSelection *selection, gpointer data)
 	can_remove = TRUE;
     }
 
-  gtk_widget_set_sensitive (button, can_remove);   
+  gtk_widget_set_sensitive (button, can_remove);
 }
 
 static void
@@ -1834,6 +1851,8 @@ setup_dialog (GladeXML *dialog)
   custom_shortcut_dialog = WID ("custom-shortcut-dialog");
   custom_shortcut_name_entry = WID ("custom-shortcut-name-entry");
   custom_shortcut_command_entry = WID ("custom-shortcut-command-entry");
+  gtk_dialog_set_default_response (GTK_DIALOG (custom_shortcut_dialog),
+				   GTK_RESPONSE_OK);
   gtk_window_set_transient_for (GTK_WINDOW (custom_shortcut_dialog),
                                 GTK_WINDOW (widget));
 }
