@@ -1038,8 +1038,6 @@ create_app_item (BookmarkAgent *this, const gchar *uri)
 
 	GnomeDesktopItem *ditem;
 	gchar *uri_new = NULL;
-	gchar *name;
-
 
 	ditem = libslab_gnome_desktop_item_new_from_unknown_id (uri);
 
@@ -1051,18 +1049,6 @@ create_app_item (BookmarkAgent *this, const gchar *uri)
 	if (! uri_new)
 		return;
 
-	name = g_bookmark_file_get_title (priv->store, uri, NULL);
-	if (! libslab_strcmp (name, "Help"))
-		g_bookmark_file_set_title (priv->store, uri, _("Help"));
-	else if (! libslab_strcmp (name, "Lock Screen"))
-		g_bookmark_file_set_title (priv->store, uri, _("Lock Screen"));
-	else if (! libslab_strcmp (name, "Logout"))
-		g_bookmark_file_set_title (priv->store, uri, _("Logout"));
-	else if (! libslab_strcmp (name, "Shutdown"))
-		g_bookmark_file_set_title (priv->store, uri, _("Shutdown"));
-
-	g_free (name);
-
 	if (libslab_strcmp (uri, uri_new))
 		g_bookmark_file_move_item (priv->store, uri, uri_new, NULL);
 
